fbchat\_muqit.ImageAttachment
=============================

.. currentmodule:: fbchat_muqit

.. autoclass:: ImageAttachment

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ImageAttachment.__copy__
      ~ImageAttachment.__delattr__
      ~ImageAttachment.__dir__
      ~ImageAttachment.__eq__
      ~ImageAttachment.__format__
      ~ImageAttachment.__ge__
      ~ImageAttachment.__getattribute__
      ~ImageAttachment.__getstate__
      ~ImageAttachment.__gt__
      ~ImageAttachment.__hash__
      ~ImageAttachment.__init__
      ~ImageAttachment.__init_subclass__
      ~ImageAttachment.__le__
      ~ImageAttachment.__lt__
      ~ImageAttachment.__ne__
      ~ImageAttachment.__new__
      ~ImageAttachment.__reduce__
      ~ImageAttachment.__reduce_ex__
      ~ImageAttachment.__replace__
      ~ImageAttachment.__repr__
      ~ImageAttachment.__rich_repr__
      ~ImageAttachment.__setattr__
      ~ImageAttachment.__sizeof__
      ~ImageAttachment.__str__
      ~ImageAttachment.__subclasshook__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ImageAttachment.filename
      ~ImageAttachment.id
      ~ImageAttachment.large_preview
      ~ImageAttachment.original_dimensions
      ~ImageAttachment.original_extension
      ~ImageAttachment.preview
      ~ImageAttachment.render_as_sticker
      ~ImageAttachment.thumbnail
      ~ImageAttachment.type
      ~ImageAttachment.__annotations__
      ~ImageAttachment.__doc__
      ~ImageAttachment.__module__
      ~ImageAttachment.__slots__
      ~ImageAttachment.__struct_config__
      ~ImageAttachment.__struct_defaults__
      ~ImageAttachment.__struct_encode_fields__
      ~ImageAttachment.__struct_fields__
   
   